@@ -2,16 +2,18 @@
 cat("```{r, include=FALSE}", '
 # write a manifest to local folder
 cat("
-library(MASS)
+library(darts)
 ",
 file = "manifest.R")
 ', "```", sep = "")
 
 ## ---- echo=FALSE, comment=""---------------------------------------------
+oldLibPaths <- .libPaths()
+
 cat("```{r, include=FALSE}", '
 # Create .checkpoint folder (in tempdir for this example)
 td <- tempdir()
-dir.create(file.path(td, ".checkpoint"), recursive = TRUE)
+dir.create(file.path(td, ".checkpoint"), recursive = TRUE, showWarnings = FALSE)
 
 # Create the checkpoint
 library(checkpoint)
@@ -21,12 +23,13 @@ checkpoint("2017-03-28", checkpointLocation = td)
 ## ----checkpoint, warning=FALSE-------------------------------------------
 # write a manifest to local folder
 cat('
-library(MASS)
+library(darts)
 ',
 file = "manifest.R")
 
 # Create .checkpoint folder (in tempdir for this example)
-dir.create(file.path(tempdir(), ".checkpoint"), recursive = TRUE)
+dir.create(file.path(tempdir(), ".checkpoint"), recursive = TRUE, showWarnings = FALSE)
+options(install.packages.compile.from.source = "no")
 
 # Create the checkpoint
 library(checkpoint)
@@ -41,15 +44,27 @@ checkpoint("2017-03-28", checkpointLocation = tempdir())
 ## ------------------------------------------------------------------------
 installed.packages()[, "Package"]
 
-## ---- warning=FALSE------------------------------------------------------
-library(MASS)
-hist(islands)
+## ---- warning=FALSE, fig.asp=4/3-----------------------------------------
+# Example from ?darts
+library(darts)
+x = c(12,16,19,3,17,1,25,19,17,50,18,1,3,17,2,2,13,18,16,2,25,5,5,
+      1,5,4,17,25,25,50,3,7,17,17,3,3,3,7,11,10,25,1,19,15,4,1,5,12,17,16,
+      50,20,20,20,25,50,2,17,3,20,20,20,5,1,18,15,2,3,25,12,9,3,3,19,16,20,
+      5,5,1,4,15,16,5,20,16,2,25,6,12,25,11,25,7,2,5,19,17,17,2,12)
+mod = simpleEM(x, niter=100)
+e = simpleExpScores(mod$s.final)
+oldpar <- par(mfrow=c(1, 2))
+drawHeatmap(e)
+drawBoard(new=TRUE)
+drawAimSpot(e, cex = 5)
+par(oldpar)
 
-## ---- include=FALSE------------------------------------------------------
+## ---- include=TRUE-------------------------------------------------------
 # clean up
 
-detach("package:MASS", unload = TRUE)
+detach("package:darts", unload = TRUE)
 unlink("manifest.R")
 unlink(file.path(tempdir(), ".checkpoint"), recursive = TRUE)
-unCheckpoint()
+unCheckpoint(oldLibPaths)
+.libPaths()
 
